# Version history

## 0.4.3

- Fix future being awaited multiple times.

## 0.4.2

- Fix task being awaited multiple times.

## 0.4.1

- Add `task.cancel(raise_exception=False)`.

## 0.4.0

- Launch task in `create_task()`, passing an external task group.

## 0.3.0

- Fix `Task`.

## 0.2.0

- Add `Task` and `create_task`.

## 0.1.0

- Add CI.

## 0.0.0
